@@ -81,6 +81,8 @@ class TestMain(object):
             'Unexpected silent settings were parsed'
         assert parsed_args.with_solvent is False, \
             'Unexpected with_solvent settings were parsed'
+        assert parsed_args.conformations_info_path is None, \
+            'Unexpected conformations_path settings were parsed'
 
         # Test custom shorts
         parsed_args = parse_args(['toluene.pdb',
@@ -109,6 +111,8 @@ class TestMain(object):
             'Unexpected silent settings were parsed'
         assert parsed_args.with_solvent is False, \
             'Unexpected with_solvent settings were parsed'
+        assert parsed_args.conformations_info_path is None, \
+            'Unexpected conformations_path settings were parsed'
 
         # Test custom longs
         parsed_args = parse_args(['methane.pdb',
@@ -138,6 +142,8 @@ class TestMain(object):
             'Unexpected silent settings were parsed'
         assert parsed_args.with_solvent is False, \
             'Unexpected with_solvent settings were parsed'
+        assert parsed_args.conformations_info_path is None, \
+            'Unexpected conformations_path settings were parsed'
 
         # Test unexpected charge method
         with pytest.raises(SystemExit) as pytest_wrapped_e:
@@ -170,6 +176,8 @@ class TestMain(object):
             'Unexpected silent settings were parsed'
         assert parsed_args.with_solvent is False, \
             'Unexpected with_solvent settings were parsed'
+        assert parsed_args.conformations_info_path is None, \
+            'Unexpected conformations_path settings were parsed'
 
         # Test charges_from_file argument
         parsed_args = parse_args(['BHP.pdb',
@@ -197,6 +205,8 @@ class TestMain(object):
             'Unexpected silent settings were parsed'
         assert parsed_args.with_solvent is False, \
             'Unexpected with_solvent settings were parsed'
+        assert parsed_args.conformations_info_path is None, \
+            'Unexpected conformations_path settings were parsed'
 
         # Test include_terminal_rotamers argument
         parsed_args = parse_args(['methane.pdb',
@@ -222,6 +232,35 @@ class TestMain(object):
             'Unexpected silent settings were parsed'
         assert parsed_args.with_solvent is False, \
             'Unexpected with_solvent settings were parsed'
+        assert parsed_args.conformations_info_path is None, \
+            'Unexpected conformations_path settings were parsed'
+
+        # Test chain argument
+        parsed_args = parse_args(['LYS_BNZ.pdb',
+                                  '--chain', 'L'])
+
+        assert parsed_args.as_datalocal is False, \
+            'Unexpected as_datalocal settings were parsed'
+        assert parsed_args.charge_method == 'am1bcc', \
+            'Unexpected charge_method settings were parsed'
+        assert parsed_args.debug is False, \
+            'Unexpected debug settings were parsed'
+        assert parsed_args.forcefield == 'openff_unconstrained-1.3.0.offxml', \
+            'Unexpected forcefield settings were parsed'
+        assert parsed_args.include_terminal_rotamers is False, \
+            'Unexpected include_terminal_rotamers settings were parsed'
+        assert parsed_args.output is None, \
+            'Unexpected output settings were parsed'
+        assert parsed_args.pdb_file == 'LYS_BNZ.pdb', \
+            'Unexpected pdb_file settings were parsed'
+        assert parsed_args.resolution == 30, \
+            'Unexpected resolution settings were parsed'
+        assert parsed_args.silent is False, \
+            'Unexpected silent settings were parsed'
+        assert parsed_args.with_solvent is False, \
+            'Unexpected with_solvent settings were parsed'
+        assert parsed_args.chain == 'L',\
+            'Unexpected chain settings were parsed'
 
         # Test silent argument
         parsed_args = parse_args(['methane.pdb',
@@ -247,6 +286,8 @@ class TestMain(object):
             'Unexpected silent settings were parsed'
         assert parsed_args.with_solvent is False, \
             'Unexpected with_solvent settings were parsed'
+        assert parsed_args.conformations_info_path is None, \
+            'Unexpected conformations_path settings were parsed'
 
         parse_args(['methane.pdb', '-s']) == parse_args(['methane.pdb',
                                                          '--silent'])
@@ -275,10 +316,39 @@ class TestMain(object):
             'Unexpected silent settings were parsed'
         assert parsed_args.with_solvent is False, \
             'Unexpected with_solvent settings were parsed'
+        assert parsed_args.conformations_info_path is None, \
+            'Unexpected conformations_path settings were parsed'
 
         parse_args(['methane.pdb', '-d']) == parse_args(['methane.pdb',
                                                          '--debug'])
 
+        # Test dihedral library arguments
+        parsed_args = parse_args(['methane.pdb',
+                                  '--conformations_info_path', 'test_path'])
+
+        assert parsed_args.as_datalocal is False, \
+            'Unexpected as_datalocal settings were parsed'
+        assert parsed_args.charge_method == 'am1bcc', \
+            'Unexpected charge_method settings were parsed'
+        assert parsed_args.debug is False, \
+            'Unexpected debug settings were parsed'
+        assert parsed_args.forcefield == 'openff_unconstrained-1.3.0.offxml', \
+            'Unexpected forcefield settings were parsed'
+        assert parsed_args.include_terminal_rotamers is False, \
+            'Unexpected include_terminal_rotamers settings were parsed'
+        assert parsed_args.output is None, \
+            'Unexpected output settings were parsed'
+        assert parsed_args.pdb_file == 'methane.pdb', \
+            'Unexpected pdb_file settings were parsed'
+        assert parsed_args.resolution == 30, \
+            'Unexpected resolution settings were parsed'
+        assert parsed_args.silent is False, \
+            'Unexpected silent settings were parsed'
+        assert parsed_args.with_solvent is False, \
+            'Unexpected with_solvent settings were parsed'
+        assert parsed_args.conformations_info_path == "test_path", \
+            'Unexpected conformations_path settings were parsed'
+
     def test_peleffy_main(self):
         """It checks the main function of peleffy."""
         from peleffy.main import parse_args, main
